
From: Jeffrey Mahoney <jeffm@novell.com>

This patch moves the assignment of i_priv_object to a static inline.  This is
in preparation for selinux support in reiserfs.

Signed-off-by: Jeff Mahoney <jeffm@novell.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/reiserfs/inode.c            |    2 ++
 25-akpm/fs/reiserfs/namei.c            |    2 +-
 25-akpm/fs/reiserfs/xattr.c            |    6 +++---
 25-akpm/fs/reiserfs/xattr_acl.c        |    2 +-
 25-akpm/include/linux/reiserfs_xattr.h |    6 ++++++
 5 files changed, 13 insertions(+), 5 deletions(-)

diff -puN fs/reiserfs/inode.c~reiserfs-private-inode-abstracted-to-static-inline fs/reiserfs/inode.c
--- 25/fs/reiserfs/inode.c~reiserfs-private-inode-abstracted-to-static-inline	2004-11-30 01:24:15.188336744 -0800
+++ 25-akpm/fs/reiserfs/inode.c	2004-11-30 01:24:15.200334920 -0800
@@ -1849,6 +1849,8 @@ int reiserfs_new_inode (struct reiserfs_
     } else if (inode->i_sb->s_flags & MS_POSIXACL) {
 	reiserfs_warning (inode->i_sb, "ACLs aren't enabled in the fs, "
 			  "but vfs thinks they are!");
+    } else if (is_reiserfs_priv_object (dir)) {
+	reiserfs_mark_inode_private (inode);
     }
 
     insert_inode_hash (inode);
diff -puN fs/reiserfs/namei.c~reiserfs-private-inode-abstracted-to-static-inline fs/reiserfs/namei.c
--- 25/fs/reiserfs/namei.c~reiserfs-private-inode-abstracted-to-static-inline	2004-11-30 01:24:15.190336440 -0800
+++ 25-akpm/fs/reiserfs/namei.c	2004-11-30 01:24:15.201334768 -0800
@@ -353,7 +353,7 @@ static struct dentry * reiserfs_lookup (
 
 	/* Propogate the priv_object flag so we know we're in the priv tree */
 	if (is_reiserfs_priv_object (dir))
-	    REISERFS_I(inode)->i_flags |= i_priv_object;
+	    reiserfs_mark_inode_private (inode);
     }
     reiserfs_write_unlock(dir->i_sb);
     if ( retval == IO_ERROR ) {
diff -puN fs/reiserfs/xattr_acl.c~reiserfs-private-inode-abstracted-to-static-inline fs/reiserfs/xattr_acl.c
--- 25/fs/reiserfs/xattr_acl.c~reiserfs-private-inode-abstracted-to-static-inline	2004-11-30 01:24:15.191336288 -0800
+++ 25-akpm/fs/reiserfs/xattr_acl.c	2004-11-30 01:24:15.202334616 -0800
@@ -337,7 +337,7 @@ reiserfs_inherit_default_acl (struct ino
      * would be useless since permissions are ignored, and a pain because
      * it introduces locking cycles */
     if (is_reiserfs_priv_object (dir)) {
-        REISERFS_I(inode)->i_flags |= i_priv_object;
+        reiserfs_mark_inode_private (inode);
         goto apply_umask;
     }
 
diff -puN fs/reiserfs/xattr.c~reiserfs-private-inode-abstracted-to-static-inline fs/reiserfs/xattr.c
--- 25/fs/reiserfs/xattr.c~reiserfs-private-inode-abstracted-to-static-inline	2004-11-30 01:24:15.193335984 -0800
+++ 25-akpm/fs/reiserfs/xattr.c	2004-11-30 01:24:15.203334464 -0800
@@ -182,7 +182,7 @@ open_xa_dir (const struct inode *inode, 
             return ERR_PTR (-ENODATA);
         }
         /* Newly created object.. Need to mark it private */
-        REISERFS_I(xadir->d_inode)->i_flags |= i_priv_object;
+        reiserfs_mark_inode_private (xadir->d_inode);
     }
 
     dput (xaroot);
@@ -231,7 +231,7 @@ get_xa_file_dentry (const struct inode *
             goto out;
         }
         /* Newly created object.. Need to mark it private */
-        REISERFS_I(xafile->d_inode)->i_flags |= i_priv_object;
+        reiserfs_mark_inode_private (xafile->d_inode);
     }
 
 out:
@@ -1316,7 +1316,7 @@ reiserfs_xattr_init (struct super_block 
 
       if (!err && dentry) {
           s->s_root->d_op = &xattr_lookup_poison_ops;
-          REISERFS_I(dentry->d_inode)->i_flags |= i_priv_object;
+          reiserfs_mark_inode_private (dentry->d_inode);
           REISERFS_SB(s)->priv_root = dentry;
       } else if (!(mount_flags & MS_RDONLY)) { /* xattrs are unavailable */
           /* If we're read-only it just means that the dir hasn't been
diff -puN include/linux/reiserfs_xattr.h~reiserfs-private-inode-abstracted-to-static-inline include/linux/reiserfs_xattr.h
--- 25/include/linux/reiserfs_xattr.h~reiserfs-private-inode-abstracted-to-static-inline	2004-11-30 01:24:15.194335832 -0800
+++ 25-akpm/include/linux/reiserfs_xattr.h	2004-11-30 01:24:15.203334464 -0800
@@ -103,6 +103,12 @@ reiserfs_read_unlock_xattr_i(struct inod
     up_read (&REISERFS_I(inode)->xattr_sem);
 }
 
+static inline void
+reiserfs_mark_inode_private(struct inode *inode)
+{
+    REISERFS_I(inode)->i_flags |= i_priv_object;
+}
+
 #else
 
 #define is_reiserfs_priv_object(inode) 0
_
